@@ -16,6 +16,8 @@ enum class BamRecordTag
     DELETION_QV,
     DELETION_TAG,
     HOLE_NUMBER,
+    FORWARD_IPD,
+    FORWARD_PW,
     INSERTION_QV,
     IPD,
     LABEL_QV,
@@ -38,12 +40,16 @@ enum class BamRecordTag
     QUERY_START_FRAME_NUMBER,
     READ_ACCURACY,
     READ_GROUP,
+    REVERSE_IPD,
+    REVERSE_PW,
     SCRAP_REGION_TYPE,
     SCRAP_ZMW_TYPE,
     SIGNAL_TO_NOISE,
     START_FRAME,
     SUBSTITUTION_QV,
     SUBSTITUTION_TAG,
+    BASEMOD_LOCI,
+    BASEMOD_QV,
 
     //
     // not tags per se, but faking these here to simplify data fetching
