@@ -3,6 +3,11 @@
 
 #include <pbbam/Config.h>
 
+#include <pbbam/BamFile.h>
+#include <pbbam/BamHeader.h>
+#include <pbbam/DataSetTypes.h>
+#include <pbbam/GenomicInterval.h>
+
 #include <chrono>
 #include <iosfwd>
 #include <memory>
@@ -10,11 +15,6 @@
 #include <string>
 #include <vector>
 
-#include <pbbam/BamFile.h>
-#include <pbbam/BamHeader.h>
-#include <pbbam/DataSetTypes.h>
-#include <pbbam/GenomicInterval.h>
-
 namespace PacBio {
 namespace BAM {
 
@@ -89,7 +89,7 @@ public:
     /// \param[in] type dataset type
     /// \throws std::runtime_error if \p type is unknown
     ///
-    DataSet(const DataSet::TypeEnum type);
+    DataSet(DataSet::TypeEnum type);
 
     /// \brief Constructs a DataSet from a %BAM file.
     ///
@@ -325,6 +325,13 @@ public:
     ///
     const BAM::SubDataSets& SubDataSets() const;
 
+    /// \brief Fetches the dataset's SupplementalResources element.
+    ///
+    /// \returns const reference to child element
+    /// \throws std::runtime_error if element does not exist
+    ///
+    const BAM::SupplementalResources& SupplementalResources() const;
+
     /// \}
 
 public:
@@ -424,6 +431,12 @@ public:
     ///
     std::set<std::string> SequencingChemistries() const;
 
+    /// \returns sample names (SM tag) for all read groups in this dataset
+    ///
+    /// \sa ReadGroupInfo::Sample
+    ///
+    std::set<std::string> Samples() const;
+
     /// \brief Return a minimal list of genomic intervals covered by filters.
     ///
     /// \returns vector of genomic intervals
@@ -680,7 +693,7 @@ public:
     /// \param[in] type  new dataset type
     /// \returns reference to this dataset object
     ///
-    DataSet& Type(const BAM::DataSet::TypeEnum type);
+    DataSet& Type(BAM::DataSet::TypeEnum type);
 
     /// \}
 
@@ -728,6 +741,14 @@ public:
     ///
     BAM::SubDataSets& SubDataSets();
 
+    /// \brief Fetches the dataset's SupplementalResources element.
+    ///
+    /// This element will be created if it does not yet exist.
+    ///
+    /// \returns non-const reference to child element
+    ///
+    BAM::SupplementalResources& SupplementalResources();
+
     /// \}
 
 public:
@@ -779,6 +800,15 @@ public:
     ///
     DataSet& SubDataSets(const BAM::SubDataSets& subdatasets);
 
+    /// \brief Sets this dataset's SupplementalResources element.
+    ///
+    /// This element will be created if it does not yet exist.
+    ///
+    /// \param[in] resources  new value for the element
+    /// \returns reference to this dataset object
+    ///
+    DataSet& SupplementalResources(const BAM::SupplementalResources& resources);
+
     /// \}
 
 public:
