@@ -3,13 +3,13 @@
 
 #include <pbbam/Config.h>
 
-#include <cstdint>
+#include <boost/variant.hpp>
 
 #include <iosfwd>
 #include <string>
 #include <vector>
 
-#include <boost/variant.hpp>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -107,7 +107,7 @@ public:
     ///
     /// \throws runtime_error if \p modifier is not valid for int8_t data
     ///
-    Tag(int8_t value, const TagModifier mod);
+    Tag(int8_t value, TagModifier mod);
 
     /// \brief Creates a Tag from an unsigned 8-bit integer or character.
     ///
@@ -364,7 +364,7 @@ public:
     std::string Typename() const;
 
     /// \returns true if tag data modifier \p m is set
-    bool HasModifier(const TagModifier m) const;
+    bool HasModifier(TagModifier m) const;
 
     /// \returns current tag data modifier
     TagModifier Modifier() const;
@@ -374,7 +374,7 @@ public:
     /// \param[in] m    new modifier value
     ///
     /// \returns reference to this tag
-    Tag& Modifier(const TagModifier m);
+    Tag& Modifier(TagModifier m);
 
     /// \}
 
@@ -383,7 +383,15 @@ public:
     ///
     friend std::ostream& operator<<(std::ostream& out, const Tag& tag);
 
-private:
+    ///
+    /// \returns estimated number of bytes used by this tag value
+    ///
+    /// \warning The actual usage is heavily implementation-dependent, w.r.t.
+    ///          data structure layout and alignment. A general estimate is
+    ///          provided here, but no guarantee can be made.
+    ///
+    int EstimatedBytesUsed() const noexcept;
+
     // clang-format off
     // NOTE - keep this synced with TagDataType enum ordering
     using var_t = boost::variant<boost::blank, // <-- default constructor creates variant of this type
@@ -402,10 +410,11 @@ private:
                                  std::vector<int32_t>,
                                  std::vector<uint32_t>,
                                  std::vector<float> >;
+    // clang-format on
 
+private:
     var_t data_;
     TagModifier modifier_ = TagModifier::NONE;
-    // clang-format on
 };
 
 }  // namespace BAM
