@@ -3,13 +3,13 @@
 
 #include <pbbam/Config.h>
 
+#include <pbbam/FastaSequence.h>
+#include <pbbam/internal/QueryBase.h>
+
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <pbbam/FastaSequence.h>
-#include <pbbam/internal/QueryBase.h>
-
 namespace PacBio {
 namespace BAM {
 
@@ -29,7 +29,7 @@ public:
     /// Actual chunk count may be smaller than the requested number, if the input
     /// size is smaller.
     ///
-    ZmwChunkedFastaReader(const std::string& fn, const size_t numChunks);
+    ZmwChunkedFastaReader(const std::string& fn, size_t numChunks);
 
     ZmwChunkedFastaReader(ZmwChunkedFastaReader&&) noexcept;
     ZmwChunkedFastaReader& operator=(ZmwChunkedFastaReader&&) noexcept;
