@@ -3,31 +3,28 @@
 
 #include <pbbam/Config.h>
 
-#include <cassert>
+#include <pbbam/Position.h>
+#include <pbbam/vcf/VcfHeaderTypes.h>
 
+#include <optional>
 #include <string>
 #include <unordered_map>
 #include <vector>
 
-#include <boost/optional.hpp>
-
-#include <pbbam/Position.h>
-#include <pbbam/vcf/VcfHeaderTypes.h>
-
 namespace PacBio {
 namespace VCF {
 
 struct InfoField
 {
     std::string id;
-    boost::optional<std::string> value;
-    boost::optional<std::vector<std::string>> values;
+    std::optional<std::string> value;
+    std::optional<std::vector<std::string>> values;
 };
 
 struct GenotypeData
 {
-    boost::optional<std::string> value;
-    boost::optional<std::vector<std::string>> values;
+    std::optional<std::string> value;
+    std::optional<std::vector<std::string>> values;
 };
 
 struct GenotypeField
@@ -86,11 +83,11 @@ public:
 
     bool HasInfoField(const std::string& id) const;
 
-    const boost::optional<std::string> InfoValue(const std::string& id) const;
-    VcfVariant& InfoValue(const std::string& id, boost::optional<std::string> value);
+    const std::optional<std::string> InfoValue(const std::string& id) const;
+    VcfVariant& InfoValue(const std::string& id, std::optional<std::string> value);
 
-    const boost::optional<std::vector<std::string>> InfoValues(const std::string& id) const;
-    VcfVariant& InfoValues(const std::string& id, boost::optional<std::vector<std::string>> values);
+    const std::optional<std::vector<std::string>> InfoValues(const std::string& id) const;
+    VcfVariant& InfoValues(const std::string& id, std::optional<std::vector<std::string>> values);
 
 public:
     // sample genotypes
@@ -103,18 +100,18 @@ public:
     std::vector<GenotypeField> Genotypes() const;
     VcfVariant& Genotypes(std::vector<GenotypeField> genotypes);
 
-    const boost::optional<std::string>& GenotypeValue(const size_t sampleIndex,
-                                                      const std::string& id) const;
-    VcfVariant& GenotypeValue(const size_t sampleIndex, const std::string& id,
-                              boost::optional<std::string> value);
+    const std::optional<std::string>& GenotypeValue(size_t sampleIndex,
+                                                    const std::string& id) const;
+    VcfVariant& GenotypeValue(size_t sampleIndex, const std::string& id,
+                              std::optional<std::string> value);
 
-    const boost::optional<std::vector<std::string>>& GenotypeValues(const size_t sampleIndex,
-                                                                    const std::string& id) const;
-    VcfVariant& GenotypeValues(const size_t sampleIndex, const std::string& id,
-                               boost::optional<std::vector<std::string>> values);
+    const std::optional<std::vector<std::string>>& GenotypeValues(size_t sampleIndex,
+                                                                  const std::string& id) const;
+    VcfVariant& GenotypeValues(size_t sampleIndex, const std::string& id,
+                               std::optional<std::vector<std::string>> values);
 
-    bool IsSampleHeterozygous(const size_t sampleIndex) const;
-    bool IsSamplePhased(const size_t sampleIndex) const;
+    bool IsSampleHeterozygous(size_t sampleIndex) const;
+    bool IsSamplePhased(size_t sampleIndex) const;
 
 private:
     // FIXED data
