@@ -2,16 +2,15 @@
 
 #include <pbbam/BaiIndexedBamReader.h>
 
-#include <cassert>
-#include <cstddef>
+#include <pbbam/BaiIndexCache.h>
+#include <pbbam/Deleters.h>
+#include "ErrnoReason.h"
 
 #include <sstream>
 #include <stdexcept>
 
-#include <pbbam/BaiIndexCache.h>
-#include <pbbam/Deleters.h>
-
-#include "ErrnoReason.h"
+#include <cassert>
+#include <cstddef>
 
 namespace PacBio {
 namespace BAM {
@@ -22,7 +21,9 @@ public:
     BaiIndexedBamReaderPrivate(BamFile file, const std::shared_ptr<BaiIndexCacheData>& index)
         : file_{std::move(file)}, index_{index}
     {
-        if (!index_) index_ = std::make_shared<BaiIndexCacheData>(file_);
+        if (!index_) {
+            index_ = std::make_shared<BaiIndexCacheData>(file_);
+        }
         assert(index_);  // should throw in cache load if failed
     }
 
