@@ -3,14 +3,14 @@
 
 #include <pbbam/Config.h>
 
-#include <cassert>
+#include <pbbam/BamRecord.h>
+#include <pbbam/BamRecordImpl.h>
+#include <pbbam/BamRecordTag.h>
 
 #include <string>
 #include <unordered_map>
 
-#include <pbbam/BamRecord.h>
-#include <pbbam/BamRecordImpl.h>
-#include <pbbam/BamRecordTag.h>
+#include <cassert>
 
 namespace PacBio {
 namespace BAM {
@@ -19,8 +19,10 @@ class BamRecordTags
 {
 public:
     // tag info
-    static bool IsPulse(const BamRecordTag tag);
-    static std::string LabelFor(const BamRecordTag tag);
+    static bool IsIPD(BamRecordTag tag);
+    static bool IsPulse(BamRecordTag tag);
+    static bool IsPW(BamRecordTag tag);
+    static std::string LabelFor(BamRecordTag tag);
 
 private:
     struct BamRecordTagData
@@ -33,12 +35,24 @@ private:
     static const TagLookupType tagLookup;
 };
 
+inline bool BamRecordTags::IsIPD(const BamRecordTag tag)
+{
+    return tag == BamRecordTag::IPD || tag == BamRecordTag::FORWARD_IPD ||
+           tag == BamRecordTag::REVERSE_IPD;
+}
+
 inline bool BamRecordTags::IsPulse(const BamRecordTag tag)
 {
     assert(tagLookup.find(tag) != tagLookup.cend());
     return tagLookup.at(tag).isPulse_;
 }
 
+inline bool BamRecordTags::IsPW(const BamRecordTag tag)
+{
+    return tag == BamRecordTag::PULSE_WIDTH || tag == BamRecordTag::FORWARD_PW ||
+           tag == BamRecordTag::REVERSE_PW;
+}
+
 inline std::string BamRecordTags::LabelFor(const BamRecordTag tag)
 {
     assert(tagLookup.find(tag) != tagLookup.cend());
