@@ -1,20 +1,14 @@
-// File Description
-/// \file BgzipFastaWriter.cpp
-/// \brief Implements the BgzipFastaWriter class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/BgzipFastaWriter.h"
+#include <pbbam/BgzipFastaWriter.h>
+
+#include <pbbam/BamRecord.h>
+#include <pbbam/FastqSequence.h>
+#include <pbbam/FormatUtils.h>
 
 #include <sstream>
 #include <stdexcept>
 
-#include "pbbam/BamRecord.h"
-#include "pbbam/FastqSequence.h"
-#include "pbbam/FormatUtils.h"
-
 namespace PacBio {
 namespace BAM {
 
@@ -34,8 +28,6 @@ BgzipFastaWriter::BgzipFastaWriter(const std::string& fn, const BgzipWriterConfi
     }
 }
 
-void BgzipFastaWriter::TryFlush() {}
-
 void BgzipFastaWriter::Write(const BamRecordImpl& bam) { Write(bam.Name(), bam.Sequence()); }
 
 void BgzipFastaWriter::Write(const FastaSequence& fastq) { Write(fastq.Name(), fastq.Bases()); }
