@@ -1,8 +1,6 @@
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/internal/DataSetElement.h"
+#include <pbbam/internal/DataSetElement.h>
 
 #include "DataSetUtils.h"
 
