@@ -10,19 +10,23 @@ namespace BAM {
 class EntireFileQuery::EntireFileQueryPrivate
 {
 public:
-    EntireFileQueryPrivate(const DataSet &dataset) : reader_{dataset} {}
+    EntireFileQueryPrivate(const DataSet& dataset) : reader_{dataset} {}
 
     SequentialCompositeBamReader reader_;
 };
 
-EntireFileQuery::EntireFileQuery(const DataSet &dataset)
+EntireFileQuery::EntireFileQuery(const DataSet& dataset)
     : internal::IQuery{}, d_(new EntireFileQueryPrivate(dataset))
 {
 }
 
+EntireFileQuery::EntireFileQuery(EntireFileQuery&&) noexcept = default;
+
+EntireFileQuery& EntireFileQuery::operator=(EntireFileQuery&&) noexcept = default;
+
 EntireFileQuery::~EntireFileQuery() = default;
 
-bool EntireFileQuery::GetNext(BamRecord &r) { return d_->reader_.GetNext(r); }
+bool EntireFileQuery::GetNext(BamRecord& r) { return d_->reader_.GetNext(r); }
 
 }  // namespace BAM
 }  // namespace PacBio
