@@ -2,17 +2,19 @@
 
 #include "ErrnoReason.h"
 
+#include <iostream>
+
 #include <cerrno>
 #include <cstring>
 
-#include <iostream>
-
 namespace PacBio {
 namespace BAM {
 
 void MaybePrintErrnoReason(std::ostream& out)
 {
-    if (errno != 0) out << "\n  reason: " << std::strerror(errno);
+    if (errno != 0) {
+        out << "\n  reason: " << std::strerror(errno);
+    }
 }
 
 }  // namespace BAM
