@@ -2,7 +2,8 @@
 
 #include <pbbam/FastaReader.h>
 
-#include <cassert>
+#include <pbbam/FormatUtils.h>
+#include "KSeqReader.h"
 
 #include <algorithm>
 #include <sstream>
@@ -11,18 +12,9 @@
 #include <type_traits>
 #include <vector>
 
-#include <pbbam/FormatUtils.h>
-
-#include "KSeqReader.h"
-
 namespace PacBio {
 namespace BAM {
 
-static_assert(!std::is_copy_constructible<FastaReader>::value,
-              "FastaReader(const FastaReader&) is not = delete");
-static_assert(!std::is_copy_assignable<FastaReader>::value,
-              "FastaReader& operator=(const FastaReader&) is not = delete");
-
 class FastaReader::FastaReaderPrivate
 {
 public:
@@ -41,7 +33,9 @@ public:
     bool GetNext(FastaSequence& record)
     {
         const auto readOk = reader_->ReadNext();
-        if (!readOk) return false;  // not error, could be EOF
+        if (!readOk) {
+            return false;  // not error, could be EOF
+        }
 
         record = FastaSequence{reader_->Name(), reader_->Bases()};
         return true;
@@ -68,8 +62,9 @@ std::vector<FastaSequence> FastaReader::ReadAll(const std::string& fn)
     std::vector<FastaSequence> result;
     result.reserve(256);
     FastaReader reader{fn};
-    for (const auto& seq : reader)
+    for (const auto& seq : reader) {
         result.emplace_back(seq);
+    }
     return result;
 }
 
