@@ -2,24 +2,16 @@
 
 #include <pbbam/FastqReader.h>
 
-#include <cassert>
+#include <pbbam/FormatUtils.h>
+#include "KSeqReader.h"
 
 #include <sstream>
 #include <stdexcept>
 #include <type_traits>
 
-#include <pbbam/FormatUtils.h>
-
-#include "KSeqReader.h"
-
 namespace PacBio {
 namespace BAM {
 
-static_assert(!std::is_copy_constructible<FastqReader>::value,
-              "FastqReader(const FastqReader&) is not = delete");
-static_assert(!std::is_copy_assignable<FastqReader>::value,
-              "FastqReader& operator=(const FastqReader&) is not = delete");
-
 class FastqReader::FastqReaderPrivate
 {
 public:
@@ -38,7 +30,9 @@ public:
     bool GetNext(FastqSequence& record)
     {
         const auto ok = reader_->ReadNext();
-        if (!ok) return false;  // not error, could be EOF
+        if (!ok) {
+            return false;  // not error, could be EOF
+        }
 
         record = FastqSequence{reader_->Name(), reader_->Bases(), reader_->Qualities()};
         return true;
@@ -65,8 +59,9 @@ std::vector<FastqSequence> FastqReader::ReadAll(const std::string& fn)
     std::vector<FastqSequence> result;
     result.reserve(256);
     FastqReader reader{fn};
-    for (const auto& seq : reader)
+    for (const auto& seq : reader) {
         result.emplace_back(seq);
+    }
     return result;
 }
 
