@@ -11,8 +11,9 @@ std::vector<std::string> FofnReader::Files(std::istream& in)
 {
     std::vector<std::string> files;
     std::string fn;
-    while (std::getline(in, fn))
+    while (std::getline(in, fn)) {
         files.push_back(fn);
+    }
     return files;
 }
 
