@@ -1,12 +1,6 @@
-// File Description
-/// \file IFastaWriter.cpp
-/// \brief Implements the IFastaWriter class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/IFastaWriter.h"
+#include <pbbam/IFastaWriter.h>
 
 namespace PacBio {
 namespace BAM {
