@@ -1,12 +1,6 @@
-// File Description
-/// \file IFastqWriter.cpp
-/// \brief Implements the IFastqWriter class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/IFastqWriter.h"
+#include <pbbam/IFastqWriter.h>
 
 namespace PacBio {
 namespace BAM {
