@@ -2,13 +2,13 @@
 
 #include "KSeqReader.h"
 
-#include <cassert>
+#include "ErrnoReason.h"
 
 #include <sstream>
 #include <stdexcept>
 #include <vector>
 
-#include "ErrnoReason.h"
+#include <cassert>
 
 namespace PacBio {
 namespace BAM {
@@ -44,8 +44,9 @@ std::string KSeqReader::Qualities() const { return std::string{seq_->qual.s, seq
 bool KSeqReader::ReadNext()
 {
     const auto result = kseq_read(seq_.get());
-    if (result == -1)  // EOF
+    if (result == -1) {  // EOF
         return false;
+    }
     return true;
 }
 
