@@ -2,16 +2,18 @@
 
 #include <pbbam/PbiFilterTypes.h>
 
-#include <cassert>
-#include <cstddef>
-#include <cstdint>
-
-#include <string>
-#include <unordered_map>
+#include <pbbam/StringUtilities.h>
 
 #include <boost/algorithm/string.hpp>
 
-#include <pbbam/StringUtilities.h>
+#include <algorithm>
+#include <optional>
+#include <string>
+#include <unordered_map>
+
+#include <cassert>
+#include <cstddef>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -55,7 +57,9 @@ IndexList readLengthHelper(const std::vector<T>& start, const std::vector<T>& en
                     Compare::TypeToName(cmp)};
         }
 
-        if (keep) result.push_back(i);
+        if (keep) {
+            result.push_back(i);
+        }
     }
     return result;
 }
@@ -105,10 +109,11 @@ PbiMovieNameFilter::PbiMovieNameFilter(const std::vector<std::string>& movieName
                                        const Compare::Type cmp)
     : cmp_{cmp}
 {
-    if (cmp_ == Compare::EQUAL)
+    if (cmp_ == Compare::EQUAL) {
         cmp_ = Compare::CONTAINS;
-    else if (cmp_ == Compare::NOT_EQUAL)
+    } else if (cmp_ == Compare::NOT_EQUAL) {
         cmp_ = Compare::NOT_CONTAINS;
+    }
 
     if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
         throw std::runtime_error{
@@ -117,6 +122,7 @@ PbiMovieNameFilter::PbiMovieNameFilter(const std::vector<std::string>& movieName
             "Movie name filter can only compare equality or presence in whitelist/blacklist."};
     }
 
+    // clang-format off
     for (const auto& movieName : movieNames) {
         candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "CCS")));
         candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "TRANSCRIPT")));
@@ -126,8 +132,17 @@ PbiMovieNameFilter::PbiMovieNameFilter(const std::vector<std::string>& movieName
         candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "SCRAP")));
         candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "UNKNOWN")));
         candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "ZMW")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "CCS")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "TRANSCRIPT")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "POLYMERASE")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "HQREGION")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "SUBREAD")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "SCRAP")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "UNKNOWN")));
+        candidateRgIds_.insert(ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "ZMW")));
         movieNames_.insert(movieName);
     }
+    // clang-format on
 }
 
 bool PbiMovieNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
@@ -137,10 +152,14 @@ bool PbiMovieNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
         // straightforward lookup
         const auto& rgId = index.BasicData().rgId_.at(i);
         const auto foundAt = candidateRgIds_.find(rgId);
-        if (foundAt != candidateRgIds_.cend()) return true;
+        if (foundAt != candidateRgIds_.cend()) {
+            return true;
+        }
 
         // if no barcode context available, record movie name fails
-        if (!index.HasBarcodeData()) return false;
+        if (!index.HasBarcodeData()) {
+            return false;
+        }
 
         // try barcoded RG IDs
         const auto& barcodeData = index.BarcodeData();
@@ -148,23 +167,47 @@ bool PbiMovieNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
             std::make_pair(barcodeData.bcForward_.at(i), barcodeData.bcReverse_.at(i));
         for (const auto& movieName : movieNames_) {
             const auto tryBarcodedType = [&](const std::string& readType) {
-                const int32_t barcodedId =
+                int32_t barcodedId =
                     ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, readType, barcodes));
                 if (barcodedId == rgId) {
                     candidateRgIds_.insert(barcodedId);  // found combo, save for future lookup
                     return true;
                 }
+
+                barcodedId =
+                    ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, readType, barcodes));
+                if (barcodedId == rgId) {
+                    candidateRgIds_.insert(barcodedId);  // found combo, save for future lookup
+                    return true;
+                }
+
                 return false;
             };
 
-            if (tryBarcodedType("CCS")) return true;
-            if (tryBarcodedType("TRANSCRIPT")) return true;
-            if (tryBarcodedType("SUBREAD")) return true;
-            if (tryBarcodedType("ZMW")) return true;
-            if (tryBarcodedType("POLYMERASE")) return true;
-            if (tryBarcodedType("HQREGION")) return true;
-            if (tryBarcodedType("SCRAP")) return true;
-            if (tryBarcodedType("UNKNOWN")) return true;
+            if (tryBarcodedType("CCS")) {
+                return true;
+            }
+            if (tryBarcodedType("TRANSCRIPT")) {
+                return true;
+            }
+            if (tryBarcodedType("SUBREAD")) {
+                return true;
+            }
+            if (tryBarcodedType("ZMW")) {
+                return true;
+            }
+            if (tryBarcodedType("POLYMERASE")) {
+                return true;
+            }
+            if (tryBarcodedType("HQREGION")) {
+                return true;
+            }
+            if (tryBarcodedType("SCRAP")) {
+                return true;
+            }
+            if (tryBarcodedType("UNKNOWN")) {
+                return true;
+            }
         }
 
         // not found at all
@@ -196,7 +239,7 @@ struct PbiNumSubreadsFilter::PbiNumSubreadsFilterPrivate
     bool Accepts(const PbiRawData& idx, const size_t row) const
     {
         // lazy-load
-        if (!lookup_.is_initialized()) {
+        if (!lookup_) {
             InitializeLookup(idx);
         }
         const auto holeNumber = idx.BasicData().holeNumber_[row];
@@ -217,19 +260,23 @@ struct PbiNumSubreadsFilter::PbiNumSubreadsFilterPrivate
         int count = 0;
         while (current < zmws.cend()) {
             if (*start != *current) {
-                if (shouldKeep(count)) lookup_->insert(*start);
+                if (shouldKeep(count)) {
+                    lookup_->insert(*start);
+                }
                 start = current;
                 count = 0;
             }
             ++count;
             ++current;
         }
-        if (shouldKeep(count)) lookup_->insert(*start);
+        if (shouldKeep(count)) {
+            lookup_->insert(*start);
+        }
     }
 
     int numSubreads_;
     Compare::Type cmp_;
-    mutable boost::optional<std::set<int32_t>> lookup_;  // mutable for lazy-load
+    mutable std::optional<std::set<int32_t>> lookup_;  // mutable for lazy-load
 };
 
 PbiNumSubreadsFilter::PbiNumSubreadsFilter(int numSubreads, const Compare::Type cmp)
@@ -242,6 +289,10 @@ PbiNumSubreadsFilter::PbiNumSubreadsFilter(const PbiNumSubreadsFilter& other)
 {
 }
 
+PbiNumSubreadsFilter::PbiNumSubreadsFilter(PbiNumSubreadsFilter&&) noexcept = default;
+
+PbiNumSubreadsFilter& PbiNumSubreadsFilter::operator=(PbiNumSubreadsFilter&&) noexcept = default;
+
 PbiNumSubreadsFilter::~PbiNumSubreadsFilter() = default;
 
 bool PbiNumSubreadsFilter::Accepts(const PbiRawData& idx, const size_t row) const
@@ -267,9 +318,8 @@ struct PbiQueryNameFilter::PbiQueryNameFilterPrivate
 public:
     using QueryInterval = std::pair<int32_t, int32_t>;
     using QueryIntervals = std::set<QueryInterval>;
-    using ZmwLookup = std::unordered_map<int32_t, QueryIntervals>;
-    using ZmwLookupPtr = std::shared_ptr<ZmwLookup>;  // may be shared by more than one rgId
-    using RgIdLookup = std::unordered_map<int32_t, ZmwLookupPtr>;
+    using ZmwData = std::unordered_map<int32_t, std::optional<QueryIntervals>>;
+    using RgIdLookup = std::unordered_map<int32_t, std::shared_ptr<ZmwData>>;
 
     PbiQueryNameFilterPrivate(const std::vector<std::string>& queryNames,
                               const Compare::Type cmp = Compare::EQUAL)
@@ -277,12 +327,13 @@ public:
     {
         for (const auto& queryName : queryNames) {
 
-            if (queryName.find("transcript/") == 0)
+            if (queryName.find("transcript/") == 0) {
                 HandleName(queryName, RecordType::TRANSCRIPT);
-            else if (queryName.find("/ccs") != std::string::npos)
+            } else if (queryName.find("/ccs") != std::string::npos) {
                 HandleName(queryName, RecordType::CCS);
-            else
+            } else {
                 HandleName(queryName, RecordType::UNKNOWN);
+            }
         }
     }
 
@@ -302,39 +353,55 @@ public:
             // see if row's RGID known
             const auto& rgId = basicData.rgId_.at(row);
             const auto rgFound = lookup_.find(rgId);
-            if (rgFound == lookup_.end()) return false;
+            if (rgFound == lookup_.end()) {
+                return false;
+            }
 
             // see if row's ZMW known
             const auto& zmwPtr = rgFound->second;
             const auto zmw = basicData.holeNumber_.at(row);
             const auto zmwFound = zmwPtr->find(zmw);
-            if (zmwFound == zmwPtr->end()) return false;
+            if (zmwFound == zmwPtr->end()) {
+                return false;
+            }
 
             // see if row's QueryStart/QueryEnd known
             // CCS names already covered in lookup construction phase
             const auto& queryIntervals = zmwFound->second;
-            const auto qStart = basicData.qStart_.at(row);
-            const auto qEnd = basicData.qEnd_.at(row);
-            const auto queryInterval = std::make_pair(qStart, qEnd);
-            return (queryIntervals.find(queryInterval) != queryIntervals.end());
+            if (queryIntervals) {
+                const auto qStart = basicData.qStart_.at(row);
+                const auto qEnd = basicData.qEnd_.at(row);
+                const QueryInterval queryInterval = std::make_pair(qStart, qEnd);
+                return (queryIntervals->find(queryInterval) != queryIntervals->end());
+            } else {
+                // CCS or transcript record
+                return true;
+            }
         }();
 
-        if (cmp_ == Compare::EQUAL || cmp_ == Compare::CONTAINS)
+        if (cmp_ == Compare::EQUAL || cmp_ == Compare::CONTAINS) {
             return found;
-        else if (cmp_ == Compare::NOT_EQUAL || cmp_ == Compare::NOT_CONTAINS)
+        } else if (cmp_ == Compare::NOT_EQUAL || cmp_ == Compare::NOT_CONTAINS) {
             return !found;
-        else
+        } else {
             throw std::runtime_error{
                 "[pbbam] PBI filter ERROR: unsupported compare type on query name filter"};
+        }
     }
 
     std::vector<int32_t> CandidateRgIds(const std::string& movieName, const RecordType type)
     {
-        if (type == RecordType::CCS)
-            return {ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "CCS"))};
+        if (type == RecordType::CCS) {
+            return {
+                ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "CCS")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "CCS")),
+            };
+        }
 
-        if (type == RecordType::TRANSCRIPT)
-            return {ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "TRANSCRIPT"))};
+        if (type == RecordType::TRANSCRIPT) {
+            return {ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "TRANSCRIPT")),
+                    ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "TRANSCRIPT"))};
+        }
 
         // we can't know for sure from QNAME alone
         return {ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "POLYMERASE")),
@@ -342,79 +409,91 @@ public:
                 ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "SUBREAD")),
                 ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "SCRAP")),
                 ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "UNKNOWN")),
-                ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "ZMW"))};
+                ReadGroupInfo::IdToInt(MakeReadGroupId(movieName, "ZMW")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "POLYMERASE")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "HQREGION")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "SUBREAD")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "SCRAP")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "UNKNOWN")),
+                ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(movieName, "ZMW"))};
     }
 
     void HandleName(const std::string& queryName, const RecordType type)
     {
-        // split name into main parts
         const auto nameParts = Split(queryName, '/');
-
-        // verify syntax
-        if (IsCcsOrTranscript(type)) {
-            if (nameParts.size() != 2) {
-                const auto typeName = (type == RecordType::CCS) ? "CCS" : "transcript";
-                throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
-                                         ") is not valid for PacBio " + typeName +
-                                         " reads. See spec for details."};
-            }
-        } else {
-            if (nameParts.size() != 3) {
-                throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
-                                         ") is not a valid PacBio BAM QNAME. See spec for details"};
-            }
+        if (nameParts.size() < 2) {
+            throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
+                                     ") is not a valid PacBio BAM QNAME. See spec for details"};
         }
 
         // generate candidate read group IDs from movie name & record type, then
         // add to lookup table
-        const auto zmwPtr = UpdateRgLookup(CandidateRgIds(nameParts.at(0), type));
+        const std::shared_ptr<ZmwData> zmw = UpdateRgLookup(CandidateRgIds(nameParts.at(0), type));
+
+        // add ZMW to read group. Add qStart/qEnd to ZMW if not a CCS/transcript record
+        const auto zmwId = [&]() {
+            try {
+                return std::stoi(nameParts.at(1));
+            } catch (const std::invalid_argument&) {
+                throw std::runtime_error{
+                    "[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
+                    ") is not a valid PacBio BAM QNAME. ZMW id must be a number."};
+            }
+        }();
+
+        if (IsCcsOrTranscript(type)) {
+            zmw->emplace(zmwId, std::optional<QueryIntervals>{});
+        } else {
 
-        // add qStart/qEnd interval to zmw lookup
-        const auto zmw = std::stoi(nameParts.at(1));
-        if (IsCcsOrTranscript(type))
-            UpdateZmwQueryIntervals(zmwPtr.get(), zmw, -1, -1);
-        else {
             const auto queryIntervalParts = Split(nameParts.at(2), '_');
             if (queryIntervalParts.size() != 2) {
                 throw std::runtime_error{"[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
                                          ") is not a valid PacBio BAM QNAME. See spec for details"};
             }
-            UpdateZmwQueryIntervals(zmwPtr.get(), zmw, std::stoi(queryIntervalParts.at(0)),
-                                    std::stoi(queryIntervalParts.at(1)));
+
+            const auto queryInterval = [&]() {
+                try {
+                    return std::make_pair(std::stoi(queryIntervalParts.at(0)),
+                                          std::stoi(queryIntervalParts.at(1)));
+                } catch (const std::invalid_argument&) {
+                    throw std::runtime_error{
+                        "[pbbam] PBI filter ERROR: requested QNAME (" + queryName +
+                        ") is not a valid PacBio BAM QNAME. qStart/qEnd must be numbers."};
+                }
+            }();
+
+            const auto zmwResult = zmw->emplace(zmwId, QueryIntervals{});
+            const auto zmwIter = zmwResult.first;
+            auto& queryIntervals = zmwIter->second;
+            queryIntervals->emplace(queryInterval);
         }
     }
 
-    ZmwLookupPtr UpdateRgLookup(std::vector<int32_t>&& rgIds)
+    std::shared_ptr<ZmwData> UpdateRgLookup(const std::vector<int32_t>& rgIds)
     {
         assert(!rgIds.empty());
 
-        ZmwLookupPtr zmwPtr;
+        std::shared_ptr<ZmwData> zmw;
 
         const auto rgFound = lookup_.find(rgIds.front());
         if (rgFound == lookup_.end()) {
-            zmwPtr = std::make_shared<ZmwLookup>();
+            zmw = std::make_shared<ZmwData>();
             for (const auto& rg : rgIds) {
-                assert(lookup_.find(rg) == lookup_.end());
-                lookup_.emplace(rg, zmwPtr);
+                // Extra RG hashes (fixed & legacy) have been calculated as
+                // candidates, but sometimes these are the same. Only store once.
+                if (lookup_.find(rg) == lookup_.end()) {
+                    lookup_.emplace(rg, zmw);
+                }
             }
         } else {
 #ifndef NDEBUG
-            for (const auto& rg : rgIds)
+            for (const auto& rg : rgIds) {
                 assert(lookup_.find(rg) != lookup_.end());
+            }
 #endif
-            zmwPtr = rgFound->second;
+            zmw = rgFound->second;
         }
-        return zmwPtr;
-    }
-
-    // add QS/QE pair to ZMW lookup
-    void UpdateZmwQueryIntervals(ZmwLookup* const zmwPtr, const int32_t zmw,
-                                 const int32_t queryStart, const int32_t queryEnd)
-    {
-        const auto zmwFound = zmwPtr->find(zmw);
-        if (zmwFound == zmwPtr->end()) zmwPtr->emplace(zmw, QueryIntervals{});
-        auto& queryIntervals = zmwPtr->at(zmw);
-        queryIntervals.emplace(std::make_pair(queryStart, queryEnd));
+        return zmw;
     }
 
 private:
@@ -439,6 +518,10 @@ PbiQueryNameFilter::PbiQueryNameFilter(const PbiQueryNameFilter& other)
 {
 }
 
+PbiQueryNameFilter::PbiQueryNameFilter(PbiQueryNameFilter&&) noexcept = default;
+
+PbiQueryNameFilter& PbiQueryNameFilter::operator=(PbiQueryNameFilter&&) noexcept = default;
+
 PbiQueryNameFilter::~PbiQueryNameFilter() = default;
 
 bool PbiQueryNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
@@ -451,25 +534,10 @@ bool PbiQueryNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
 PbiReadGroupFilter::PbiReadGroupFilter(const std::vector<int32_t>& rgIds, const Compare::Type cmp)
     : cmp_{cmp}
 {
-    if (cmp_ == Compare::EQUAL)
-        cmp_ = Compare::CONTAINS;
-    else if (cmp_ == Compare::NOT_EQUAL)
-        cmp_ = Compare::NOT_CONTAINS;
-
-    if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
-        throw std::runtime_error{
-            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp) +
-            ") for this property. "
-            "Read group filter can only compare equality or presence in whitelist/blacklist."};
-    }
-
-    // Add RG ID & empty filter if not present. The empty filter will work for
-    // non-barcoded IDs that match the expected number(s).
-    //
-    for (const auto& rgId : rgIds) {
-        const auto found = lookup_.find(rgId);
-        if (found == lookup_.cend()) lookup_.emplace(rgId, boost::none);
-    }
+    std::vector<ReadGroupInfo> readGroups{rgIds.size()};
+    std::transform(rgIds.cbegin(), rgIds.cend(), readGroups.begin(),
+                   [](const int32_t rgId) { return ReadGroupInfo{ReadGroupInfo::IntToId(rgId)}; });
+    AddReadGroups(readGroups);
 }
 
 PbiReadGroupFilter::PbiReadGroupFilter(const int32_t rgId, const Compare::Type cmp)
@@ -481,38 +549,7 @@ PbiReadGroupFilter::PbiReadGroupFilter(const std::vector<ReadGroupInfo>& readGro
                                        const Compare::Type cmp)
     : cmp_{cmp}
 {
-    if (cmp_ == Compare::EQUAL)
-        cmp_ = Compare::CONTAINS;
-    else if (cmp_ == Compare::NOT_EQUAL)
-        cmp_ = Compare::NOT_CONTAINS;
-
-    if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
-        throw std::runtime_error{
-            "[pbbam] PBI filter ERROR: unsupported compare type (" + Compare::TypeToName(cmp) +
-            ") for this property. "
-            "Read group filter can only compare equality or presence in whitelist/blacklist."};
-    }
-
-    for (const auto& rg : readGroups) {
-        // Add RG base ID with no filter if not present. The empty filter will
-        // work for non-barcoded IDs. We'll add to it if the base read group ID
-        // also has barcode labels,so that any barcode pair whitelisted for this
-        // read group filter will be a match.
-        //
-        const auto idNum = ReadGroupInfo::IdToInt(rg.BaseId());
-        const auto found = lookup_.find(idNum);
-        if (found == lookup_.cend()) lookup_.emplace(idNum, boost::none);
-
-        // Maybe add barcodes to base ID
-        const auto barcodes = rg.Barcodes();
-        if (barcodes) {
-            const auto bcFor = static_cast<int16_t>(barcodes->first);
-            const auto bcRev = static_cast<int16_t>(barcodes->second);
-            auto& idBarcodes = lookup_.at(idNum);
-            if (!idBarcodes) idBarcodes = std::vector<std::pair<int16_t, int16_t>>{};
-            idBarcodes->push_back(std::make_pair(bcFor, bcRev));
-        }
-    }
+    AddReadGroups(readGroups);
 }
 
 PbiReadGroupFilter::PbiReadGroupFilter(const ReadGroupInfo& rg, const Compare::Type cmp)
@@ -522,46 +559,98 @@ PbiReadGroupFilter::PbiReadGroupFilter(const ReadGroupInfo& rg, const Compare::T
 
 PbiReadGroupFilter::PbiReadGroupFilter(const std::vector<std::string>& rgIds,
                                        const Compare::Type cmp)
+    : cmp_{cmp}
 {
-    std::vector<ReadGroupInfo> readGroups;
-    for (const auto& rgId : rgIds)
-        readGroups.push_back(rgId);
-    *this = PbiReadGroupFilter{readGroups, cmp};
+    std::vector<ReadGroupInfo> readGroups{rgIds.size()};
+    std::transform(rgIds.cbegin(), rgIds.cend(), readGroups.begin(),
+                   [](const std::string& rgId) { return ReadGroupInfo{rgId}; });
+    AddReadGroups(readGroups);
 }
 
-PbiReadGroupFilter::PbiReadGroupFilter(const std::string& rgId, const Compare::Type cmp)
-    : PbiReadGroupFilter{ReadGroupInfo{rgId}, cmp}
+PbiReadGroupFilter::PbiReadGroupFilter(const std::string& rgId,
+                                       const Compare::Type cmp)  //: cmp_{cmp}
+    : PbiReadGroupFilter{std::vector<std::string>{rgId}, cmp}
 {
 }
 
 bool PbiReadGroupFilter::Accepts(const PbiRawData& idx, const size_t row) const
 {
-    const auto accepted = [this](const PbiRawData& index, const size_t i) {
-        // Check that read group base ID is found.
-        const auto rowRgId = index.BasicData().rgId_.at(i);
-        const auto foundAt = lookup_.find(rowRgId);
-        if (foundAt == lookup_.cend()) return false;
-
-        // Read group's base ID is found, check for filtered barcodes.
-        //
-        // For non-barcoded read groups, the filter is empty. This is
-        // essentially a no-op for allowing all candidate rows.
-        //
-        const auto& barcodes = foundAt->second;
-        if (!barcodes) return true;
-
-        // Return success on first match, otherwise no match found.
-        for (const auto& bcPair : *barcodes) {
-            if (index.BarcodeData().bcForward_.at(i) == bcPair.first &&
-                index.BarcodeData().bcReverse_.at(i) == bcPair.second) {
-                return true;
-            }
+    const auto DoFiltersMatch = [&](const int32_t rowRgId) {
+        const auto foundInFilterList = readGroups_.find(rowRgId);
+        if (foundInFilterList == readGroups_.cend()) {
+            return false;
         }
-        return false;
-    }(idx, row);
 
-    assert(cmp_ == Compare::CONTAINS || cmp_ == Compare::NOT_CONTAINS);
-    return (cmp_ == Compare::CONTAINS ? accepted : !accepted);
+        // matching ID found, check for potential barcode requirements
+
+        if (idx.HasBarcodeData()) {
+            const int16_t rowBcForward = idx.BarcodeData().bcForward_.at(row);
+            const int16_t rowBcReverse = idx.BarcodeData().bcReverse_.at(row);
+
+            for (const auto& filterReadGroup : foundInFilterList->second) {
+                const auto& filterBarcodes = filterReadGroup.Barcodes();
+                if (filterBarcodes) {
+                    const int16_t filterBcForward = filterBarcodes->first;
+                    const int16_t filterBcReverse = filterBarcodes->second;
+                    if ((rowBcForward == filterBcForward) && (rowBcReverse == filterBcReverse)) {
+                        // found matching barcodes
+                        return true;
+                    }
+                }
+            }
+
+            // no read groups in filter match this index row's barcodes
+            return false;
+        } else {
+            for (const auto& filterReadGroup : foundInFilterList->second) {
+                const auto& filterBarcodes = filterReadGroup.Barcodes();
+                if (!filterBarcodes) {
+                    // found a read group that matches ID & does not require a barcode match
+                    return true;
+                }
+            }
+
+            // all filter read groups require barcodes, but index does not
+            // contain any barcode information
+            return false;
+        }
+    };
+
+    const int rowRgId = idx.BasicData().rgId_.at(row);
+    const bool rowMatched = DoFiltersMatch(rowRgId);
+    const bool lookingForEquality = (cmp_ == Compare::CONTAINS) || (cmp_ == Compare::EQUAL);
+    return (lookingForEquality ? rowMatched : !rowMatched);
+}
+
+void PbiReadGroupFilter::AddReadGroups(const std::vector<ReadGroupInfo>& readGroups)
+{
+    if (cmp_ == Compare::EQUAL) {
+        cmp_ = Compare::CONTAINS;
+    } else if (cmp_ == Compare::NOT_EQUAL) {
+        cmp_ = Compare::NOT_CONTAINS;
+    }
+
+    if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
+        throw std::runtime_error{"[pbbam] PBI filter ERROR: unsupported compare type (" +
+                                 Compare::TypeToName(cmp_) +
+                                 ") for this property. Read group filter can only compare equality "
+                                 "or presence in whitelist/blacklist."};
+    }
+
+    //
+    // Ensure we track all potential representations of a read group's ID.
+    //
+    // NOTE: Storing the read group object more than once for equivalent IDs is
+    //       allowed here. The matching phase does a linear walk over the read groups
+    //       stored here to determine a match. This does not change the result.
+    //
+    for (const auto& rg : readGroups) {
+        const std::string rgId = rg.Id();
+        readGroups_[ReadGroupInfo::IdToInt(rgId)].push_back(rg);
+        readGroups_[ReadGroupInfo::IdToInt(ReadGroupInfo::GetBaseId(rgId))].push_back(rg);
+        readGroups_[ReadGroupInfo::IdToInt(MakeReadGroupId(rg))].push_back(rg);
+        readGroups_[ReadGroupInfo::IdToInt(MakeLegacyReadGroupId(rg))].push_back(rg);
+    }
 }
 
 // PbiReferenceNameFilter
@@ -581,7 +670,9 @@ PbiReferenceNameFilter::PbiReferenceNameFilter(std::vector<std::string> rnames,
 
 bool PbiReferenceNameFilter::Accepts(const PbiRawData& idx, const size_t row) const
 {
-    if (!initialized_) Initialize(idx);
+    if (!initialized_) {
+        Initialize(idx);
+    }
     return subFilter_.Accepts(idx, row);
 }
 
@@ -594,7 +685,7 @@ void PbiReferenceNameFilter::Initialize(const PbiRawData& idx) const
     const BamFile bamFile{bamFilename};
 
     // single-value
-    if (rnameWhitelist_ == boost::none) {
+    if (!rnameWhitelist_) {
         const auto tId = bamFile.ReferenceId(rname_);
         subFilter_ = PbiReferenceIdFilter{tId, cmp_};
     }
@@ -602,8 +693,9 @@ void PbiReferenceNameFilter::Initialize(const PbiRawData& idx) const
     // multi-value (whitelist/blacklist)
     else {
         std::vector<int32_t> ids;
-        for (const auto& rname : rnameWhitelist_.get())
+        for (const auto& rname : *rnameWhitelist_) {
             ids.push_back(bamFile.ReferenceId(rname));
+        }
         subFilter_ = PbiReferenceIdFilter{std::move(ids), cmp_};
     }
     initialized_ = true;
@@ -613,10 +705,18 @@ void PbiReferenceNameFilter::Validate() const
 {
     // double-check valid compare type
     const bool compareTypeOk = [&]() {
-        if (cmp_ == Compare::EQUAL) return true;
-        if (cmp_ == Compare::NOT_EQUAL) return true;
-        if (cmp_ == Compare::CONTAINS) return true;
-        if (cmp_ == Compare::NOT_CONTAINS) return true;
+        if (cmp_ == Compare::EQUAL) {
+            return true;
+        }
+        if (cmp_ == Compare::NOT_EQUAL) {
+            return true;
+        }
+        if (cmp_ == Compare::CONTAINS) {
+            return true;
+        }
+        if (cmp_ == Compare::NOT_CONTAINS) {
+            return true;
+        }
         return false;
     }();
     if (!compareTypeOk) {
@@ -628,5 +728,40 @@ void PbiReferenceNameFilter::Validate() const
     }
 }
 
+// PbiZmwFilter
+
+PbiZmwFilter::PbiZmwFilter(const int32_t zmw, const Compare::Type cmp) : cmp_{cmp}, singleZmw_{zmw}
+{
+}
+
+PbiZmwFilter::PbiZmwFilter(std::vector<int32_t> whitelist, const Compare::Type cmp)
+    : cmp_{cmp}, zmwLookup_{whitelist.begin(), whitelist.end()}
+{
+    // verify white list compare type
+    if (cmp_ == Compare::EQUAL) {
+        cmp_ = Compare::CONTAINS;
+    } else if (cmp_ == Compare::NOT_EQUAL) {
+        cmp_ = Compare::NOT_CONTAINS;
+    }
+    if (cmp_ != Compare::CONTAINS && cmp_ != Compare::NOT_CONTAINS) {
+        throw std::runtime_error{
+            "[pbbam] PBI filter ERROR: multi-valued filters (e.g. whitelists) can only check "
+            "for "
+            "containment."};
+    }
+}
+
+bool PbiZmwFilter::Accepts(const PbiRawData& idx, const size_t row) const
+{
+    const auto zmw = idx.BasicData().holeNumber_.at(row);
+    if (cmp_ == Compare::CONTAINS) {
+        return zmwLookup_.find(zmw) != zmwLookup_.cend();
+    } else if (cmp_ == Compare::NOT_CONTAINS) {
+        return zmwLookup_.find(zmw) == zmwLookup_.cend();
+    } else {
+        return Compare::Check(zmw, singleZmw_, cmp_);
+    }
+}
+
 }  // namespace BAM
 }  // namespace PacBio
