@@ -2,21 +2,19 @@
 
 #include <pbbam/PbiRawData.h>
 
-#include <cassert>
-#include <cstddef>
-#include <cstdint>
+#include <pbbam/BamFile.h>
+#include <pbbam/BamRecord.h>
+#include <pbbam/RecordType.h>
+#include "PbiIndexIO.h"
+
+#include <boost/numeric/conversion/cast.hpp>
 
 #include <map>
 #include <tuple>
 #include <type_traits>
 
-#include <boost/numeric/conversion/cast.hpp>
-
-#include <pbbam/BamFile.h>
-#include <pbbam/BamRecord.h>
-#include <pbbam/RecordType.h>
-
-#include "PbiIndexIO.h"
+#include <cstddef>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -25,16 +23,6 @@ namespace BAM {
 // PbiRawBarcodeData implementation
 // ----------------------------------
 
-static_assert(std::is_copy_constructible<PbiRawBarcodeData>::value,
-              "PbiRawBarcodeData(const PbiRawBarcodeData&) is not = default");
-static_assert(std::is_copy_assignable<PbiRawBarcodeData>::value,
-              "PbiRawBarcodeData& operator=(const PbiRawBarcodeData&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiRawBarcodeData>::value,
-              "PbiRawBarcodeData(PbiRawBarcodeData&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiRawBarcodeData>::value,
-              "PbiRawBarcodeData& operator=(PbiRawBarcodeData&&) is not = noexcept");
-
 PbiRawBarcodeData::PbiRawBarcodeData(uint32_t numReads)
 {
     bcForward_.reserve(numReads);
@@ -73,16 +61,6 @@ void PbiRawBarcodeData::AddRecord(const BamRecord& b)
 // PbiRawMappedData implementation
 // ----------------------------------
 
-static_assert(std::is_copy_constructible<PbiRawMappedData>::value,
-              "PbiRawMappedData(const PbiRawMappedData&) is not = default");
-static_assert(std::is_copy_assignable<PbiRawMappedData>::value,
-              "PbiRawMappedData& operator=(const PbiRawMappedData&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiRawMappedData>::value,
-              "PbiRawMappedData(PbiRawMappedData&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiRawMappedData>::value,
-              "PbiRawMappedData& operator=(PbiRawMappedData&&) is not = noexcept");
-
 PbiRawMappedData::PbiRawMappedData(uint32_t numReads)
 {
     tId_.reserve(numReads);
@@ -94,6 +72,8 @@ PbiRawMappedData::PbiRawMappedData(uint32_t numReads)
     nM_.reserve(numReads);
     nMM_.reserve(numReads);
     mapQV_.reserve(numReads);
+    nInsOps_.reserve(numReads);
+    nDelOps_.reserve(numReads);
 }
 
 void PbiRawMappedData::AddRecord(const BamRecord& b)
@@ -109,6 +89,10 @@ void PbiRawMappedData::AddRecord(const BamRecord& b)
     const auto matchesAndMismatches = b.NumMatchesAndMismatches();
     nM_.push_back(matchesAndMismatches.first);
     nMM_.push_back(matchesAndMismatches.second);
+
+    const auto insertionAndDeletionOps = b.NumInsertionAndDeletionOperations();
+    nInsOps_.push_back(insertionAndDeletionOps.first);
+    nDelOps_.push_back(insertionAndDeletionOps.second);
 }
 
 uint32_t PbiRawMappedData::NumDeletedBasesAt(size_t recordIndex) const
@@ -140,16 +124,6 @@ uint32_t PbiRawMappedData::NumInsertedBasesAt(size_t recordIndex) const
 // PbiReferenceEntry implementation
 // ------------------------------------
 
-static_assert(std::is_copy_constructible<PbiReferenceEntry>::value,
-              "PbiReferenceEntry(const PbiReferenceEntry&) is not = default");
-static_assert(std::is_copy_assignable<PbiReferenceEntry>::value,
-              "PbiReferenceEntry& operator=(const PbiReferenceEntry&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiReferenceEntry>::value,
-              "PbiReferenceEntry(PbiReferenceEntry&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiReferenceEntry>::value,
-              "PbiReferenceEntry& operator=(PbiReferenceEntry&&) is not = noexcept");
-
 const PbiReferenceEntry::ID PbiReferenceEntry::UNMAPPED_ID = static_cast<PbiReferenceEntry::ID>(-1);
 const PbiReferenceEntry::Row PbiReferenceEntry::UNSET_ROW = static_cast<PbiReferenceEntry::Row>(-1);
 
@@ -166,32 +140,12 @@ PbiReferenceEntry::PbiReferenceEntry(ID id, Row beginRow, Row endRow)
 // PbiRawReferenceData implementation
 // ------------------------------------
 
-static_assert(std::is_copy_constructible<PbiRawReferenceData>::value,
-              "PbiRawReferenceData(const PbiRawReferenceData&) is not = default");
-static_assert(std::is_copy_assignable<PbiRawReferenceData>::value,
-              "PbiRawReferenceData& operator=(const PbiRawReferenceData&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiRawReferenceData>::value,
-              "PbiRawReferenceData(PbiRawReferenceData&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiRawReferenceData>::value,
-              "PbiRawReferenceData& operator=(PbiRawReferenceData&&) is not = noexcept");
-
 PbiRawReferenceData::PbiRawReferenceData(uint32_t numRefs) { entries_.reserve(numRefs); }
 
 // ----------------------------------
 // PbiRawBasicData implementation
 // ----------------------------------
 
-static_assert(std::is_copy_constructible<PbiRawBasicData>::value,
-              "PbiRawBasicData(const PbiRawBasicData&) is not = default");
-static_assert(std::is_copy_assignable<PbiRawBasicData>::value,
-              "PbiRawBasicData& operator=(const PbiRawBasicData&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiRawBasicData>::value,
-              "PbiRawBasicData(PbiRawBasicData&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiRawBasicData>::value,
-              "PbiRawBasicData& operator=(PbiRawBasicData&&) is not = noexcept");
-
 PbiRawBasicData::PbiRawBasicData(uint32_t numReads)
 {
     rgId_.reserve(numReads);
@@ -208,7 +162,9 @@ void PbiRawBasicData::AddRecord(const BamRecord& b, int64_t offset)
 {
     // read group ID
     auto rgId = b.ReadGroupBaseId();
-    if (rgId.empty()) rgId = MakeReadGroupId(b.MovieName(), ToString(b.Type()));
+    if (rgId.empty()) {
+        rgId = MakeReadGroupId(b.MovieName(), ToString(b.Type()));
+    }
     const auto rawid = std::stoul(rgId, nullptr, 16);
     const auto id = static_cast<int32_t>(rawid);
     rgId_.push_back(id);
@@ -239,20 +195,9 @@ void PbiRawBasicData::AddRecord(const BamRecord& b, int64_t offset)
 // PbiRawData implementation
 // ----------------------------------
 
-static_assert(std::is_copy_constructible<PbiRawData>::value,
-              "PbiRawData(const PbiRawData&) is not = default");
-static_assert(std::is_copy_assignable<PbiRawData>::value,
-              "PbiRawData& operator=(const PbiRawData&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<PbiRawData>::value,
-              "PbiRawData(PbiRawData&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<PbiRawData>::value ==
-                  std::is_nothrow_move_assignable<std::string>::value,
-              "");
-
 PbiRawData::PbiRawData(std::string pbiFilename) : filename_{std::move(pbiFilename)}
 {
-    PbiIndexIO::Load(*this, filename_);
+    PbiIndexIO::LoadFromFile(*this, filename_);
 }
 
 PbiRawData::PbiRawData(const DataSet& dataset)
