@@ -3,14 +3,15 @@
 
 #include <pbbam/Config.h>
 
-#include <cassert>
-#include <cctype>
-#include <cstddef>
+#include <boost/dynamic_bitset.hpp>
+#include <boost/version.hpp>
 
 #include <string>
 #include <type_traits>
 
-#include <boost/dynamic_bitset.hpp>
+#include <cassert>
+#include <cctype>
+#include <cstddef>
 
 namespace PacBio {
 namespace BAM {
@@ -31,8 +32,9 @@ public:
         // squashed pulse   -> data[i] == 0
         //
         const auto numPulses = pulseCalls.size();
-        for (size_t i = 0; i < numPulses; ++i)
+        for (size_t i = 0; i < numPulses; ++i) {
             data_[i] = std::isupper(pulseCalls.at(i));
+        }
     }
 
     Pulse2BaseCache() = delete;
@@ -94,12 +96,37 @@ public:
         //
         size_t inputIndex = 0;
         for (size_t i = 0; i < numPulses; ++i) {
-            if (data_[i]) result.push_back(pulseData.at(inputIndex));
+            if (data_[i]) {
+                result.push_back(pulseData.at(inputIndex));
+            }
             ++inputIndex;
         }
         return result;
     }
 
+    ///
+    /// \returns estimated number of bytes used by this record
+    ///
+    /// \warning The actual usage is heavily implementation-dependent, w.r.t.
+    ///          data structure layout and alignment. A general estimate is
+    ///          provided here, but no guarantee can be made.
+    ///
+    int EstimatedBytesUsed() const
+    {
+        int result = sizeof(boost::dynamic_bitset<>);
+#if BOOST_VERSION >= 106200
+        // bitset::capacity() (added in boost v1.62) returns the number of bits
+        // that can be stored before reallocating.
+        result += (data_.capacity() / sizeof(unsigned long));
+#else
+        // Cannot directly query the underlying container size prior to v1.62.
+        // This will likely undershoot the actual space used, but this provides
+        // at least a minimum.
+        result += (data_.size() / sizeof(unsigned long));
+#endif
+        return result;
+    }
+
 private:
     boost::dynamic_bitset<> data_;
 };
