@@ -2,16 +2,15 @@
 
 #include <pbbam/SequenceInfo.h>
 
-#include <cassert>
-#include <cstdint>
+#include <pbbam/SamTagCodec.h>
+#include <pbbam/StringUtilities.h>
 
 #include <limits>
 #include <sstream>
 #include <tuple>
 #include <type_traits>
 
-#include <pbbam/SamTagCodec.h>
-#include <pbbam/StringUtilities.h>
+#include <cstdint>
 
 namespace PacBio {
 namespace BAM {
@@ -26,17 +25,6 @@ const std::string token_UR{"UR"};
 
 }  // namespace
 
-static_assert(std::is_copy_constructible<SequenceInfo>::value,
-              "SequenceInfo(const SequenceInfo&) is not = default");
-static_assert(std::is_copy_assignable<SequenceInfo>::value,
-              "SequenceInfo& operator=(const SequenceInfo&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<SequenceInfo>::value,
-              "SequenceInfo(SequenceInfo&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<SequenceInfo>::value ==
-                  std::is_nothrow_move_assignable<std::string>::value,
-              "");
-
 SequenceInfo::SequenceInfo(std::string name, std::string length)
     : name_(std::move(name)), length_(std::move(length))
 {
@@ -82,7 +70,9 @@ SequenceInfo SequenceInfo::FromSam(const std::string& sam)
 {
     // pop off '@SQ\t', then split rest of line into tokens
     const auto tokens = Split(sam.substr(4), '\t');
-    if (tokens.empty()) return {};
+    if (tokens.empty()) {
+        return {};
+    }
 
     SequenceInfo seq;
     std::map<std::string, std::string> custom;
@@ -93,18 +83,23 @@ SequenceInfo SequenceInfo::FromSam(const std::string& sam)
         auto tokenValue = token.substr(3);
 
         // set sequence info
-        // clang-format off
-        if      (tokenTag == token_SN) seq.Name(std::move(tokenValue));
-        else if (tokenTag == token_LN) seq.Length(std::move(tokenValue));
-        else if (tokenTag == token_AS) seq.AssemblyId(std::move(tokenValue));
-        else if (tokenTag == token_M5) seq.Checksum(std::move(tokenValue));
-        else if (tokenTag == token_SP) seq.Species(std::move(tokenValue));
-        else if (tokenTag == token_UR) seq.Uri(std::move(tokenValue));
-        // clang-format on
+        if (tokenTag == token_SN) {
+            seq.Name(std::move(tokenValue));
+        } else if (tokenTag == token_LN) {
+            seq.Length(std::move(tokenValue));
+        } else if (tokenTag == token_AS) {
+            seq.AssemblyId(std::move(tokenValue));
+        } else if (tokenTag == token_M5) {
+            seq.Checksum(std::move(tokenValue));
+        } else if (tokenTag == token_SP) {
+            seq.Species(std::move(tokenValue));
+        } else if (tokenTag == token_UR) {
+            seq.Uri(std::move(tokenValue));
 
-        // otherwise, "custom" tag
-        else
+            // otherwise, "custom" tag
+        } else {
             custom[tokenTag] = std::move(tokenValue);
+        }
     }
 
     seq.CustomTags(std::move(custom));
@@ -113,7 +108,9 @@ SequenceInfo SequenceInfo::FromSam(const std::string& sam)
 
 bool SequenceInfo::IsValid() const
 {
-    if (name_.empty()) return false;
+    if (name_.empty()) {
+        return false;
+    }
 
     // use long instead of int32_t, just to make sure we can catch overflow
     const long l = atol(length_.c_str());
@@ -151,17 +148,26 @@ std::string SequenceInfo::ToSam() const
     std::ostringstream out;
     out << "@SQ" << MakeSamTag(token_SN, name_);
 
-    // clang-format off
-    if (!length_.empty())     out << MakeSamTag(token_LN, length_);
-    if (!assemblyId_.empty()) out << MakeSamTag(token_AS, assemblyId_);
-    if (!checksum_.empty())   out << MakeSamTag(token_M5, checksum_);
-    if (!species_.empty())    out << MakeSamTag(token_SP, species_);
-    if (!uri_.empty())        out << MakeSamTag(token_UR, uri_);
-    // clang-format on
+    if (!length_.empty()) {
+        out << MakeSamTag(token_LN, length_);
+    }
+    if (!assemblyId_.empty()) {
+        out << MakeSamTag(token_AS, assemblyId_);
+    }
+    if (!checksum_.empty()) {
+        out << MakeSamTag(token_M5, checksum_);
+    }
+    if (!species_.empty()) {
+        out << MakeSamTag(token_SP, species_);
+    }
+    if (!uri_.empty()) {
+        out << MakeSamTag(token_UR, uri_);
+    }
 
     // append any custom tags
-    for (auto&& attribute : custom_)
+    for (auto&& attribute : custom_) {
         out << MakeSamTag(std::move(attribute.first), std::move(attribute.second));
+    }
 
     return out.str();
 }
