@@ -2,24 +2,12 @@
 
 #include <pbbam/virtual/VirtualRegion.h>
 
-#include <cassert>
-
 #include <tuple>
 #include <type_traits>
 
 namespace PacBio {
 namespace BAM {
 
-static_assert(std::is_copy_constructible<VirtualRegion>::value,
-              "VirtualRegion(const VirtualRegion&) is not = default");
-static_assert(std::is_copy_assignable<VirtualRegion>::value,
-              "VirtualRegion& operator=(const VirtualRegion&) is not = default");
-
-static_assert(std::is_nothrow_move_constructible<VirtualRegion>::value,
-              "VirtualRegion(VirtualRegion&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<VirtualRegion>::value,
-              "VirtualRegion& operator=(VirtualRegion&&) is not = noexcept");
-
 VirtualRegion::VirtualRegion(const VirtualRegionType type_, const int beginPos_, const int endPos_,
                              const int score_)
     : type{type_}, beginPos{beginPos_}, endPos{endPos_}, cxTag{}, score{score_}
