@@ -20,7 +20,9 @@ VirtualZmwBamRecord VirtualZmwCompositeReader::Next()
 {
     if (currentReader_) {
         const auto result = currentReader_->Next();
-        if (!currentReader_->HasNext()) OpenNextReader();
+        if (!currentReader_->HasNext()) {
+            OpenNextReader();
+        }
         return result;
     }
 
@@ -36,7 +38,9 @@ std::vector<BamRecord> VirtualZmwCompositeReader::NextRaw()
 {
     if (currentReader_) {
         const auto result = currentReader_->NextRaw();
-        if (!currentReader_->HasNext()) OpenNextReader();
+        if (!currentReader_->HasNext()) {
+            OpenNextReader();
+        }
         return result;
     }
 
@@ -59,7 +63,9 @@ void VirtualZmwCompositeReader::OpenNextReader()
 
         currentReader_ =
             std::make_unique<VirtualZmwReader>(nextSource.first, nextSource.second, filter_);
-        if (currentReader_->HasNext()) return;
+        if (currentReader_->HasNext()) {
+            return;
+        }
     }
 }
 
