@@ -2,11 +2,11 @@
 
 #include <pbbam/ZmwQuery.h>
 
-#include <cstdint>
-
 #include <pbbam/CompositeBamReader.h>
 #include <pbbam/PbiFilterTypes.h>
 
+#include <cstdint>
+
 namespace PacBio {
 namespace BAM {
 
@@ -26,6 +26,10 @@ ZmwQuery::ZmwQuery(std::vector<int32_t> zmwWhitelist, const DataSet& dataset)
 {
 }
 
+ZmwQuery::ZmwQuery(ZmwQuery&&) noexcept = default;
+
+ZmwQuery& ZmwQuery::operator=(ZmwQuery&&) noexcept = default;
+
 ZmwQuery::~ZmwQuery() = default;
 
 bool ZmwQuery::GetNext(BamRecord& r) { return d_->reader_.GetNext(r); }
