@@ -2,18 +2,17 @@
 
 #include <pbbam/virtual/ZmwReadStitcher.h>
 
-#include <deque>
-#include <stdexcept>
-#include <utility>
-
 #include <pbbam/DataSet.h>
 #include <pbbam/EntireFileQuery.h>
 #include <pbbam/PbiFilter.h>
 #include <pbbam/PbiFilterQuery.h>
-
 #include "VirtualStitching.h"
 #include "VirtualZmwReader.h"
 
+#include <deque>
+#include <stdexcept>
+#include <utility>
+
 namespace PacBio {
 namespace BAM {
 
@@ -40,7 +39,9 @@ public:
     {
         if (currentReader_) {
             const auto result = currentReader_->Next();
-            if (!currentReader_->HasNext()) OpenNextReader();
+            if (!currentReader_->HasNext()) {
+                OpenNextReader();
+            }
             return result;
         }
 
@@ -56,7 +57,9 @@ public:
     {
         if (currentReader_) {
             const auto result = currentReader_->NextRaw();
-            if (!currentReader_->HasNext()) OpenNextReader();
+            if (!currentReader_->HasNext()) {
+                OpenNextReader();
+            }
             return result;
         }
 
@@ -90,7 +93,9 @@ private:
 
             currentReader_ =
                 std::make_unique<VirtualZmwReader>(nextSource.first, nextSource.second, filter_);
-            if (currentReader_->HasNext()) return;
+            if (currentReader_->HasNext()) {
+                return;
+            }
         }
     }
 };
@@ -116,6 +121,10 @@ ZmwReadStitcher::ZmwReadStitcher(const DataSet& dataset)
 {
 }
 
+ZmwReadStitcher::ZmwReadStitcher(ZmwReadStitcher&&) noexcept = default;
+
+ZmwReadStitcher& ZmwReadStitcher::operator=(ZmwReadStitcher&&) noexcept = default;
+
 ZmwReadStitcher::~ZmwReadStitcher() = default;
 
 bool ZmwReadStitcher::HasNext() { return d_->HasNext(); }
