@@ -2,22 +2,15 @@
 
 #include <pbbam/bed/BedWriter.h>
 
-#include <cassert>
+#include <pbbam/GenomicInterval.h>
+#include <pbbam/TextFileWriter.h>
 
 #include <sstream>
 #include <type_traits>
 
-#include <pbbam/GenomicInterval.h>
-#include <pbbam/TextFileWriter.h>
-
 namespace PacBio {
 namespace BED {
 
-static_assert(!std::is_copy_constructible<BedWriter>::value,
-              "BedWriter(const BedWriter&) is not = delete");
-static_assert(!std::is_copy_assignable<BedWriter>::value,
-              "BedWriter& operator=(const BedWriter&) is not = delete");
-
 class BedWriter::BedWriterPrivate
 {
 public:
