@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #include <pbbam/BgzipFastaWriter.h>
 
 #include <algorithm>
@@ -27,8 +25,9 @@ TEST(BAM_BgzipFastaWriter, writes_bgzf_fasta_data_to_file)
 
     {
         BgzipFastaWriter writer{fn};
-        for (const auto& seq : sequences)
+        for (const auto& seq : sequences) {
             writer.Write(seq);
+        }
     }
     EXPECT_EQ(HtslibCompression::BGZIP, FormatUtils::CompressionType(fn));
 
