@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #include <pbbam/IndexedBamWriter.h>
 
 #include <string>
@@ -16,8 +14,6 @@
 
 #include "PbbamTestData.h"
 
-// clang-format off
-
 TEST(BAM_IndexedBamWriter, writes_valid_bam_and_pbi_on_success)
 {
     using namespace PacBio::BAM;
@@ -30,33 +26,20 @@ TEST(BAM_IndexedBamWriter, writes_valid_bam_and_pbi_on_success)
     const auto& header = file.Header();
 
     const std::vector<std::string> expectedQNames{
-        "ArminsFakeMovie/100000/2659_3025",
-        "ArminsFakeMovie/100000/3116_3628",
-        "ArminsFakeMovie/100000/3722_4267",
-        "ArminsFakeMovie/100000/4356_4864",
-        "ArminsFakeMovie/100000/4960_5477",
-        "ArminsFakeMovie/100000/5571_6087",
-        "ArminsFakeMovie/100000/6199_6719",
-        "ArminsFakeMovie/100000/6812_7034",
-        "ArminsFakeMovie/200000/2659_3025",
-        "ArminsFakeMovie/200000/3116_3628",
-        "ArminsFakeMovie/200000/3722_4267",
-        "ArminsFakeMovie/200000/4356_4864",
-        "ArminsFakeMovie/200000/4960_5477",
-        "ArminsFakeMovie/200000/5571_6087",
-        "ArminsFakeMovie/200000/6199_6719",
-        "ArminsFakeMovie/200000/6812_7034",
-        "ArminsFakeMovie/300000/2659_3025",
-        "ArminsFakeMovie/300000/3116_3628",
-        "ArminsFakeMovie/300000/3722_4267",
-        "ArminsFakeMovie/300000/4356_4864",
-        "ArminsFakeMovie/300000/4960_5477",
-        "ArminsFakeMovie/300000/5571_6087",
-        "ArminsFakeMovie/300000/6199_6719",
-        "ArminsFakeMovie/300000/6812_7034"
-    };
+        "ArminsFakeMovie/100000/2659_3025", "ArminsFakeMovie/100000/3116_3628",
+        "ArminsFakeMovie/100000/3722_4267", "ArminsFakeMovie/100000/4356_4864",
+        "ArminsFakeMovie/100000/4960_5477", "ArminsFakeMovie/100000/5571_6087",
+        "ArminsFakeMovie/100000/6199_6719", "ArminsFakeMovie/100000/6812_7034",
+        "ArminsFakeMovie/200000/2659_3025", "ArminsFakeMovie/200000/3116_3628",
+        "ArminsFakeMovie/200000/3722_4267", "ArminsFakeMovie/200000/4356_4864",
+        "ArminsFakeMovie/200000/4960_5477", "ArminsFakeMovie/200000/5571_6087",
+        "ArminsFakeMovie/200000/6199_6719", "ArminsFakeMovie/200000/6812_7034",
+        "ArminsFakeMovie/300000/2659_3025", "ArminsFakeMovie/300000/3116_3628",
+        "ArminsFakeMovie/300000/3722_4267", "ArminsFakeMovie/300000/4356_4864",
+        "ArminsFakeMovie/300000/4960_5477", "ArminsFakeMovie/300000/5571_6087",
+        "ArminsFakeMovie/300000/6199_6719", "ArminsFakeMovie/300000/6812_7034"};
 
-    {   // copy file & generate index
+    {  // copy file & generate index
 
         BamReader reader{file};
         IndexedBamWriter writer{outBam, header};
@@ -66,26 +49,24 @@ TEST(BAM_IndexedBamWriter, writes_valid_bam_and_pbi_on_success)
         }
     }
 
-    {   // sequential read of new BAM
+    {  // sequential read of new BAM
 
         BamReader reader{outBam};
         BamRecord b;
-        for (size_t i = 0; i < 24; ++i)
-        {
+        for (size_t i = 0; i < 24; ++i) {
             reader.GetNext(b);
             EXPECT_EQ(expectedQNames.at(i), b.FullName());
         }
     }
 
-    {   // check random access in new BAM, using companion PBI
+    {  // check random access in new BAM, using companion PBI
 
         const PbiRawData idx{outPbi};
         const auto& offsets = idx.BasicData().fileOffset_;
 
         BamReader reader{outBam};
         BamRecord b;
-        for (int i = 23; i >=0; --i)
-        {
+        for (int i = 23; i >= 0; --i) {
             reader.VirtualSeek(offsets.at(i));
             reader.GetNext(b);
             EXPECT_EQ(expectedQNames.at(i), b.FullName());
@@ -106,8 +87,9 @@ TEST(BAM_IndexedBamWriter, can_handle_long_reads_spanning_bgzf_blocks)
         BamFile file{inBamFn};
         IndexedBamWriter writer{outBamFn, file.Header()};
         EntireFileQuery query{file};
-        for (const auto& b : query)
+        for (const auto& b : query) {
             writer.Write(b);
+        }
     }
 
     {
@@ -116,8 +98,7 @@ TEST(BAM_IndexedBamWriter, can_handle_long_reads_spanning_bgzf_blocks)
 
         BamReader reader{outBamFn};
         BamRecord b;
-        for (int i = 0; i < 100; ++i)
-        {
+        for (int i = 0; i < 100; ++i) {
             reader.VirtualSeek(offsets.at(i));
             reader.GetNext(b);
         }
@@ -126,5 +107,3 @@ TEST(BAM_IndexedBamWriter, can_handle_long_reads_spanning_bgzf_blocks)
     remove(outBamFn.c_str());
     remove(outPbiFn.c_str());
 }
-
-// clang-format on
